@@ -205,58 +205,71 @@ fn present_dependencies(
                     } => (bump, Some(causing_dependency_names)),
                     VersionAdjustment::Changed { bump, .. } => (bump, None),
                 };
-                match &bump.next_release {
-                    Ok(next_release) => {
-                        if next_release > &dep.package.version {
-                            log::info!(
-                                "{} {}-bump {} package '{}' from {} to {} for publishing{}{}{}",
-                                will(dry_run),
-                                bump_spec,
-                                kind,
-                                dep.package.name,
-                                dep.package.version,
-                                next_release,
-                                bump.latest_release
-                                    .as_ref()
-                                    .and_then(|latest_release| {
-                                        (dep.package.version != *latest_release)
-                                            .then(|| format!(", {} on crates.io", latest_release))
-                                    })
-                                    .unwrap_or_default(),
-                                breaking_dependencies
-                                    .map(|causes| format!(
-                                        ", for SAFETY due to breaking package{} {}",
-                                        if causes.len() == 1 { "" } else { "s" },
-                                        causes.iter().map(|n| format!("'{}'", n)).collect::<Vec<_>>().join(", ")
-                                    ))
-                                    .unwrap_or_default(),
-                                (*next_release != bump.desired_release)
-                                    .then(|| format!(", ignoring computed version {}", bump.desired_release))
-                                    .unwrap_or_default(),
-                            );
-                        } else {
-                            log::info!(
-                            "Manifest version of {} package '{}' at {} is sufficient{}, ignoring computed version {}",
-                            kind,
-                            dep.package.name,
-                            dep.package.version,
-                            bump.latest_release
-                                .as_ref()
-                                .map(|latest_release| format!(" to succeed latest released version {}", latest_release))
-                                .unwrap_or_else(|| ", creating a new release 🎉".into()),
-                            bump.desired_release
-                        );
-                        }
-                    }
-                    Err(version::bump::Error::LatestReleaseMoreRecentThanDesiredOne(latest_release)) => {
+                if let Some(latest_release) = bump
+                    .latest_release
+                    .as_ref()
+                    .and_then(|lr| (*lr >= bump.desired_release).then(|| lr))
+                {
+                    let bump_flag = match dep.kind {
+                        dependency::Kind::UserSelection => "--bump <level>",
+                        dependency::Kind::DependencyOrDependentOfUserSelection => "--bump-dependencies <level>",
+                    };
+                    if bump.desired_release == bump.package_version {
                         log::warn!(
-                        "Latest published version of '{}' is {}, the new version is {}. Consider using --bump <level> or --bump-dependencies <level> or update the index with --update-crates-index.",
+                            "'{}' is unchanged. Consider using {} along with --no-bump-on-demand to force a version change.",
+                            dep.package.name,
+                            bump_flag
+                        );
+                    } else {
+                        log::warn!(
+                            "Latest published version of '{}' is {}, the new version is {}. Consider using {} or update the index with --update-crates-index.",
+                            dep.package.name,
+                            latest_release,
+                            bump.desired_release,
+                            bump_flag
+                        );
+                    }
+                    error = true;
+                }
+                if bump.next_release > dep.package.version {
+                    log::info!(
+                        "{} {}-bump {} package '{}' from {} to {} for publishing{}{}{}",
+                        will(dry_run),
+                        bump_spec,
+                        kind,
                         dep.package.name,
-                        latest_release,
+                        dep.package.version,
+                        bump.next_release,
+                        bump.latest_release
+                            .as_ref()
+                            .and_then(|latest_release| {
+                                (dep.package.version != *latest_release)
+                                    .then(|| format!(", {} on crates.io", latest_release))
+                            })
+                            .unwrap_or_default(),
+                        breaking_dependencies
+                            .map(|causes| format!(
+                                ", for SAFETY due to breaking package{} {}",
+                                if causes.len() == 1 { "" } else { "s" },
+                                causes.iter().map(|n| format!("'{}'", n)).collect::<Vec<_>>().join(", ")
+                            ))
+                            .unwrap_or_default(),
+                        (bump.next_release != bump.desired_release)
+                            .then(|| format!(", ignoring computed version {}", bump.desired_release))
+                            .unwrap_or_default(),
+                    );
+                } else {
+                    log::info!(
+                        "Manifest version of {} package '{}' at {} is sufficient{}, ignoring computed version {}",
+                        kind,
+                        dep.package.name,
+                        dep.package.version,
+                        bump.latest_release
+                            .as_ref()
+                            .map(|latest_release| format!(" to succeed latest released version {}", latest_release))
+                            .unwrap_or_else(|| ", creating a new release 🎉".into()),
                         bump.desired_release
                     );
-                        error = true;
-                    }
                 };
             }
             dependency::Mode::NotForPublishing { .. } => {}
@@ -300,14 +313,7 @@ fn present_dependencies(
                 cause,
                 deps_and_bumps
                     .into_iter()
-                    .map(|(dep_name, bump)| format!(
-                        "'{}' {} ➡ {}",
-                        dep_name,
-                        bump.package_version,
-                        bump.next_release
-                            .as_ref()
-                            .expect("bailed earlier if there was an error")
-                    ))
+                    .map(|(dep_name, bump)| format!("'{}' {} ➡ {}", dep_name, bump.package_version, bump.next_release))
                     .collect::<Vec<_>>()
                     .join(", ")
             );
